@@ -159,21 +159,9 @@ class YieldFunction(metaclass=abc.ABCMeta):
                 idx = fitting_param_names.index('equivalent_stress')
                 initial_params_all[idx] = 50e6
 
-            if 'exponent' in fitting_param_names:
-                bounds = (
-                    [-2] * (len(initial_params_all) - 1) + [1],
-                    [+2] * (len(initial_params_all) - 1) + [8],
-                )
-            else:
-                bounds = (
-                    [-2] * len(initial_params_all),
-                    [+2] * len(initial_params_all),
-                )
-
             fit = least_squares(
                 cls.residual,
                 initial_params_all,
-                bounds=bounds,
                 kwargs=dict(
                     stress_states=stress_states,
                     fitting_param_names=fitting_param_names,
@@ -226,6 +214,10 @@ class YieldFunction(metaclass=abc.ABCMeta):
 
         return out
 
+    @property
+    def name(self):
+        return self.__class__.__name__
+
     @classmethod
     def compare_3D(cls, yield_functions, normalise=True, resolution=DEF_3D_RES,
                    equivalent_stress=None, min_stress=None, max_stress=None,
